import { RequestOptionsFactory } from '@wix/sdk-types';
/**
 * Retrieves a list of a workflow's cards.
 *
 *
 * The `listCards()` function returns a Promise that resolves to a list of the specified workflow's cards.
 *
 *
 * Use the `options` parameter to specify which cards to retrieve and in which order to retrieve them. Must use either `phaseId` or `fetchOnlyArchived`.
 *
 *
 * Cards can be sorted based on their `"id"`, `"name"`, `"phaseId"`, `"createdDate"`, `"updatedDate"`, `"source"`, and `"position"`.
 *
 *
 * If no `limit` parameter is passed, the first 50 cards are returned.
 *
 *
 * Sort order defaults to by `"phaseId"` and then by `"position"` ascending.
 *
 *
 * This function requires you to specify the ID of a workflow. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
export declare function listCards(payload: object): RequestOptionsFactory<any>;
/**
 * Retrieves a workflow card by ID.
 *
 *
 * The `getCard()` function returns a Promise that resolves to the card with the specified ID.
 *
 *
 * This function requires you to specify the ID of a card. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
export declare function getCard(payload: object): RequestOptionsFactory<any>;
/**
 * Updates an existing workflow card.
 *
 *
 * The `updateCard()` function returns a Promise that resolves when the card has been updated with the specified values.
 *
 *
 * `contactId` is not a required field, but if the parameter is not passed, the field will default to empty and the card will not be associated with any contact.
 *
 *
 * This function requires you to specify the ID of a card. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
export declare function updateCard(payload: object): RequestOptionsFactory<any>;
/**
 * Creates a new workflow card.
 *
 *
 * The `createCard()` function returns a Promise that resolves to the created card's ID when the card is created in the specified workflow phase.
 *
 * Pass a value for the `position` parameter to specify the newly created card's position within the specified phase. Positions are zero-based, meaning the first position is `0`.
 *
 * When omitted, the newly created card is added to the specified phase as the top card within the phase.
 *
 *
 * This function requires you to specify the ID of a workflow and phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 *
 *  > **Note:**
 *  > Each workflow is limited to 5,000 cards.
 *  > If this limit is reached, `createCard()` throws an error.
 *  > [Archive cards](#archivecard) when they're no longer needed
 *  > to reduce card count and avoid hitting the limit.
 */
export declare function createCard(payload: object): RequestOptionsFactory<any>;
/**
 * Deletes a workflow card by ID.
 *
 *
 * The `deleteCard()` function returns a Promise when the specified card has been deleted.
 *
 * This function requires you to specify the ID of a card. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
export declare function deleteCard(payload: object): RequestOptionsFactory<any>;
/**
 * Moves a card to a new position within a workflow.
 *
 *
 * The `moveCard()` function returns a Promise when the specified card has been moved to the new position.
 *
 * Use the `options` parameter to specify the phase and position within that phase to move the card to. Positions are zero-based, meaning the first position is `0`.
 *
 * This function requires you to specify the ID of a card. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
export declare function moveCard(payload: object): RequestOptionsFactory<any>;
/**
 * Restores an archived workflow card.
 *
 *
 * The `restoreCard()` function returns a Promise that resolves when the archived card has been restored.
 *
 *
 * This function requires you to specify the ID of a card. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 *
 *
 * > **Note:**
 * > Each workflow is limited to 5,000 cards.
 * > If this limit is reached, `createCard()` throws an error.
 * > [Archive cards](#archivecard) when they're no longer needed
 * > to reduce card count and avoid hitting the limit.
 */
export declare function restoreCard(payload: object): RequestOptionsFactory<any>;
/**
 * Archives a workflow card.
 *
 *
 * The `archiveCard()` function returns a Promise that resolves when the card has been archived.
 *
 *
 * This function requires you to specify the ID of a card. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
export declare function archiveCard(payload: object): RequestOptionsFactory<any>;
