"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.archiveCard = exports.restoreCard = exports.moveCard = exports.deleteCard = exports.createCard = exports.updateCard = exports.getCard = exports.listCards = exports.WebhookIdentityType = exports.SortOrder = exports.AttachmentType = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixWorkflowsV1Card = __importStar(require("./workflows-v1-card-cards.http.js"));
/** describes the supported types of attachments (currently only supports Contact which is the default type) */
var AttachmentType;
(function (AttachmentType) {
    AttachmentType["ContactType"] = "ContactType";
})(AttachmentType || (exports.AttachmentType = AttachmentType = {}));
var SortOrder;
(function (SortOrder) {
    SortOrder["ASC"] = "ASC";
    SortOrder["DESC"] = "DESC";
})(SortOrder || (exports.SortOrder = SortOrder = {}));
var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (exports.WebhookIdentityType = WebhookIdentityType = {}));
/**
 * Retrieves a list of a workflow's cards.
 *
 *
 * The `listCards()` function returns a Promise that resolves to a list of the specified workflow's cards.
 *
 *
 * Use the `options` parameter to specify which cards to retrieve and in which order to retrieve them. Must use either `phaseId` or `fetchOnlyArchived`.
 *
 *
 * Cards can be sorted based on their `"id"`, `"name"`, `"phaseId"`, `"createdDate"`, `"updatedDate"`, `"source"`, and `"position"`.
 *
 *
 * If no `limit` parameter is passed, the first 50 cards are returned.
 *
 *
 * Sort order defaults to by `"phaseId"` and then by `"position"` ascending.
 *
 *
 * This function requires you to specify the ID of a workflow. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param workflowId - ID of the workflow whose cards will be listed.
 * @public
 * @documentationMaturity preview
 * @requiredField workflowId
 * @param options - Options to use when retrieving the list of cards.
 * @permissionId workflows.view
 * @fqn com.wixpress.workflow.api.v1.CardsService.ListCards
 */
async function listCards(workflowId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        workflowId: workflowId,
        phaseId: options?.phaseId,
        limit: options?.limit,
        offset: options?.offset,
        attachmentValue: options?.attachmentValue,
        fetchArchived: options?.fetchArchived,
        sort: options?.sort,
    });
    const reqOpts = ambassadorWixWorkflowsV1Card.listCards(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                workflowId: '$[0]',
                phaseId: '$[1].phaseId',
                limit: '$[1].limit',
                offset: '$[1].offset',
                attachmentValue: '$[1].attachmentValue',
                fetchArchived: '$[1].fetchArchived',
                sort: '$[1].sort',
            },
            singleArgumentUnchanged: false,
        }, ['workflowId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.listCards = listCards;
/**
 * Retrieves a workflow card by ID.
 *
 *
 * The `getCard()` function returns a Promise that resolves to the card with the specified ID.
 *
 *
 * This function requires you to specify the ID of a card. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param _id - ID of the card to retrieve.
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @permissionId workflows.view
 * @returns Requested card.
 * @fqn com.wixpress.workflow.api.v1.CardsService.GetCard
 */
async function getCard(_id) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({ id: _id });
    const reqOpts = ambassadorWixWorkflowsV1Card.getCard(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data)?.card;
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { id: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['_id']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.getCard = getCard;
/**
 * Updates an existing workflow card.
 *
 *
 * The `updateCard()` function returns a Promise that resolves when the card has been updated with the specified values.
 *
 *
 * `contactId` is not a required field, but if the parameter is not passed, the field will default to empty and the card will not be associated with any contact.
 *
 *
 * This function requires you to specify the ID of a card. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param _id - ID of the card to update.
 * @param cardInfo - Card details.
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @requiredField cardInfo
 * @param options - Options to use when updating a card.
 * @permissionId workflows.modify
 * @fqn com.wixpress.workflow.api.v1.CardsService.UpdateCard
 */
async function updateCard(_id, cardInfo) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        id: _id,
        cardInfo: cardInfo,
    });
    const reqOpts = ambassadorWixWorkflowsV1Card.updateCard(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { id: '$[0]', cardInfo: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['_id', 'cardInfo']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.updateCard = updateCard;
/**
 * Creates a new workflow card.
 *
 *
 * The `createCard()` function returns a Promise that resolves to the created card's ID when the card is created in the specified workflow phase.
 *
 * Pass a value for the `position` parameter to specify the newly created card's position within the specified phase. Positions are zero-based, meaning the first position is `0`.
 *
 * When omitted, the newly created card is added to the specified phase as the top card within the phase.
 *
 *
 * This function requires you to specify the ID of a workflow and phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 *
 *  > **Note:**
 *  > Each workflow is limited to 5,000 cards.
 *  > If this limit is reached, `createCard()` throws an error.
 *  > [Archive cards](#archivecard) when they're no longer needed
 *  > to reduce card count and avoid hitting the limit.
 * @param card - Card details.
 * @public
 * @documentationMaturity preview
 * @requiredField card
 * @requiredField identifiers
 * @requiredField identifiers.phaseId
 * @requiredField identifiers.workflowId
 * @param options - Options to use when creating a card.
 * @permissionId workflows.modify
 * @fqn com.wixpress.workflow.api.v1.CardsService.CreateCard
 */
async function createCard(identifiers, card, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[3];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        workflowId: identifiers?.workflowId,
        phaseId: identifiers?.phaseId,
        card: card,
        position: options?.position,
    });
    const reqOpts = ambassadorWixWorkflowsV1Card.createCard(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                workflowId: '$[0].workflowId',
                phaseId: '$[0].phaseId',
                card: '$[1]',
                position: '$[2].position',
            },
            singleArgumentUnchanged: false,
        }, ['identifiers', 'card', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.createCard = createCard;
/**
 * Deletes a workflow card by ID.
 *
 *
 * The `deleteCard()` function returns a Promise when the specified card has been deleted.
 *
 * This function requires you to specify the ID of a card. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param _id - ID of the card to delete.
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @permissionId workflows.modify
 * @fqn com.wixpress.workflow.api.v1.CardsService.DeleteCard
 */
async function deleteCard(_id) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({ id: _id });
    const reqOpts = ambassadorWixWorkflowsV1Card.deleteCard(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { id: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['_id']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.deleteCard = deleteCard;
/**
 * Moves a card to a new position within a workflow.
 *
 *
 * The `moveCard()` function returns a Promise when the specified card has been moved to the new position.
 *
 * Use the `options` parameter to specify the phase and position within that phase to move the card to. Positions are zero-based, meaning the first position is `0`.
 *
 * This function requires you to specify the ID of a card. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param _id - ID of the card to move.
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @param options - Information about where to move the card.
 * @permissionId workflows.modify
 * @fqn com.wixpress.workflow.api.v1.CardsService.MoveCard
 */
async function moveCard(_id, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        id: _id,
        newPhaseId: options?.newPhaseId,
        newPosition: options?.newPosition,
    });
    const reqOpts = ambassadorWixWorkflowsV1Card.moveCard(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                id: '$[0]',
                newPhaseId: '$[1].newPhaseId',
                newPosition: '$[1].newPosition',
            },
            singleArgumentUnchanged: false,
        }, ['_id', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.moveCard = moveCard;
/**
 * Restores an archived workflow card.
 *
 *
 * The `restoreCard()` function returns a Promise that resolves when the archived card has been restored.
 *
 *
 * This function requires you to specify the ID of a card. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 *
 *
 * > **Note:**
 * > Each workflow is limited to 5,000 cards.
 * > If this limit is reached, `createCard()` throws an error.
 * > [Archive cards](#archivecard) when they're no longer needed
 * > to reduce card count and avoid hitting the limit.
 * @param _id - ID of the card to restore.
 * @param newPhaseId - ID of the phase to restore the card to.
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @requiredField newPhaseId
 * @param options - Options to use when restoring a card.
 * @permissionId workflows.modify
 * @fqn com.wixpress.workflow.api.v1.CardsService.RestoreCard
 */
async function restoreCard(_id, newPhaseId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[3];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        id: _id,
        newPhaseId: newPhaseId,
        newPosition: options?.newPosition,
    });
    const reqOpts = ambassadorWixWorkflowsV1Card.restoreCard(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                id: '$[0]',
                newPhaseId: '$[1]',
                newPosition: '$[2].newPosition',
            },
            singleArgumentUnchanged: false,
        }, ['_id', 'newPhaseId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.restoreCard = restoreCard;
/**
 * Archives a workflow card.
 *
 *
 * The `archiveCard()` function returns a Promise that resolves when the card has been archived.
 *
 *
 * This function requires you to specify the ID of a card. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param _id - ID of the card to archive.
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @permissionId workflows.modify
 * @fqn com.wixpress.workflow.api.v1.CardsService.ArchiveCard
 */
async function archiveCard(_id) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({ id: _id });
    const reqOpts = ambassadorWixWorkflowsV1Card.archiveCard(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { id: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['_id']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.archiveCard = archiveCard;
//# sourceMappingURL=workflows-v1-card-cards.universal.js.map